@@ -3,11 +3,6 @@
 	if(returnX) 
 		 theta <-  getThetaCl(rawtheta, multimodel)[[dind]]
 	x <- compModelMass(theta, model)	
-        if(any(is.infinite(x))){
-          t1<<-theta
-          t2<<-model
-        }
-          
         if(returnX) 
 		    x <- as.vector(x) 
 	
